@@ -13,7 +13,7 @@ Copyright (c) 2020-2021 MalwareFrank
 """
 
 __author__ = """MalwareFrank"""
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 
 import struct as _struct
@@ -105,7 +105,7 @@ class dnPE(_PE):
             for s in self.net.metadata.streams_list:
                 if isinstance(s, stream.MetaDataTables):
                     s: stream.MetaDataTables
-                    dump.add_lines(self.net.mdtables.struct.dump())
+                    dump.add_lines(s.struct.dump())
                     dump.add_newline()
                     if hasattr(s, "tables_list") and s.tables_list:
                         for t in s.tables_list:
